@@ -3,7 +3,7 @@ package GitHub::Actions;
 use Exporter 'import'; # needed to use @EXPORT
 use warnings;
 use strict;
-use Carp;
+use Carp qw(croak);
 
 use v5.14;
 
@@ -12,7 +12,7 @@ our %github;
 our $EXIT_CODE = 0;
 
 our @EXPORT = qw(
-                  %github set_output set_env debug error warning
+                  %github $EXIT_CODE set_output set_env debug error warning
                   set_failed error_on_file warning_on_file
                   start_group end_group exit_action
                );
@@ -26,7 +26,7 @@ BEGIN {
   }
 }
 
-use version; our $VERSION = qv('0.1.2');
+use version; our $VERSION = qv('0.2.0');
 
 sub _write_to_github_file {
   my ($github_var, $content) = @_;
@@ -36,7 +36,7 @@ sub _write_to_github_file {
 }
 
 sub set_output {
-  carp "Need name and value" unless @_;
+  croak "Need name and value" unless @_;
   my ($output_name, $output_value) = @_;
   $output_value ||=1;
   _write_to_github_file( 'OUTPUT', "$output_name=$output_value" );
@@ -75,15 +75,19 @@ sub warning_on_file {
 sub command_on_file {
   my $command = shift;
   my $message = shift;
-  my ($file, $line, $col ) = @_;
-  if ( $file ) {
-    my @data;
-    push( @data, "file=$file");
-    push( @data, "line=$line") if $line;
-    push( @data, "col=$col") if $col;
-    $command .= " ".join(",", @data );
+  croak "Need at least a file name" unless @_;
+  my ($file, $line, $title, $col ) = @_;
+  my @data;
+  push( @data, "file=$file");
+  push( @data, "line=$line") if $line;
+  if ( $title ) {
+    push( @data, "title=$title"."::$message");
+  } else {
+    push( @data, "title=".uc(substr($command,2))."::$message");
   }
-  say $command."::$message"
+  push( @data, "col=$col") if $col;
+  $command .= " ".join(",", @data );
+  say $command;
 }
 
 sub start_group {
@@ -108,16 +112,20 @@ __END__
 
 =head1 NAME
 
-GitHub::Actions - Work in GitHub Actions using Perl
+GitHub::Actions - Work in GitHub Actions using native Perl
 
 
 =head1 VERSION
 
-This document describes GitHub::Actions version 0.1.1.1
+This document describes GitHub::Actions version 0.1.2
 
 
 =head1 SYNOPSIS
 
+This will be in the context of oa GitHub actions step. You will need to install
+via CPAN this module first, and use C<perl {0}> as C<shell>. Please see below
+this code for instructions.
+
     use GitHub::Actions;
     use v5.14;
 
@@ -135,9 +143,9 @@ This document describes GitHub::Actions version 0.1.1.1
     # Produces an error and sets exit code to 1
     error( "FOO has happened" );
 
-    # Error/warning with information on file
-    error_on_file( "There's foo", $file, $line, $col );
-    warning_on_file( "There's bar", $file, $line, $col );
+    # Error/warning with information on file. The last 3 parameters are optional
+    error_on_file( "There's foo", $file, $line, $title, $col );
+    warning_on_file( "There's bar", $file, $line, $title, $col );
 
     # Debugging messages and warnings
     debug( "Value of FOO is $bar" );
@@ -154,14 +162,14 @@ This document describes GitHub::Actions version 0.1.1.1
     # Errors and exits
     set_failed( "We're doomed" );
 
-Install this module within a GitHub action
+Install this module within a GitHub action, as a C<step>
 
-      . name: "Install GitHub::Actions"
+      - name: "Install GitHub::Actions"
         run: sudo cpan GitHub::Actions
 
-(we need C<sudo> since we're using the system Perl)
+(we need C<sudo> since we're using the system Perl that's installed in every runner)
 
-You can use this as a C<step>
+Then, as another C<step>
 
       - name: Test env variables
         shell: perl {0}
@@ -169,22 +177,23 @@ You can use this as a C<step>
           use GitHub::Actions;
           set_env( 'FOO', 'BAR');
 
-In most cases, you'll want to just have it installed locally and fatpack it to
-upload it to the repository.
+In most cases, you'll want to just have it installed locally in your repository
+and C<fatpack> it in a script that you will upload it to the repository.
 
 =head1 DESCRIPTION
 
 GitHub Actions include by default, at least in its Linux runners, a
-system Perl which you can use directly in your GitHub actions. This here is
+system Perl which you can use directly in them. This here is
 a (for the time being) minimalistic module that tries to help a bit
 with that, by defining a few functions that will be useful when
 performing GitHub actions. Besides the system Perl, you can use any of
 L<the modules
 installed|https://gist.github.com/JJ/edf3a39d68525439978da2a02763d42b>. You
 can install other modules via cpan or, preferably for speed, via the
-Ubuntu package (or equivalent)
+Ubuntu package (or equivalent).
 
-Check out an example of using it in the L<repository|https://github.com/JJ/perl-GitHub-Actions/blob/main/.github/workflows/self-test.yml>
+Check out an example of using it in the
+L<repository|https://github.com/JJ/perl-GitHub-Actions/blob/main/.github/workflows/self-test.yml>.
 
 =head1 INTERFACE
 
@@ -254,17 +263,18 @@ during the C<BEGIN> phase to be available when this module loads.
       $ENV{'GITHUB_BAR'} = 'bar';
     }
 
+You can use this for testing, for instance, if you create any module based on
+this one.
 
 =head1 DEPENDENCIES
 
-Intentionally, no dependencies are included.
-
+Intentionally, no dependencies are included. Several dependencies are used for
+testing, though.
 
 =head1 INCOMPATIBILITIES
 
 None reported.
 
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
@@ -279,7 +289,8 @@ JJ Merelo  C<< <jmerelo@CPAN.org> >>. Many thanks to RENEEB and Gabor Szabo for
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2021, JJ Merelo C<< <jmerelo@CPAN.org> >>. All rights reserved.
+Copyright (c) 2021, 2022 JJ Merelo C<< <jmerelo@CPAN.org> >>. All rights
+reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
